@@ -62,15 +62,18 @@ CamelFolderInfo *
 						 const gchar *fid);
 void		camel_ews_utils_sync_deleted_items
 						(CamelEwsFolder *ews_folder,
-						 GSList *items_deleted);
+						 GSList *items_deleted,
+						 CamelFolderChangeInfo *change_info);
 void		camel_ews_utils_sync_created_items
 						(CamelEwsFolder *ews_folder,
 						 EEwsConnection *cnc,
 						 GSList *items_created,
+						 CamelFolderChangeInfo *change_info,
 						 GCancellable *cancellable);
 void		camel_ews_utils_sync_updated_items
 						(CamelEwsFolder *ews_folder,
-						 GSList *items_updated);
+						 GSList *items_updated,
+						 CamelFolderChangeInfo *change_info);
 void		ews_utils_replace_server_user_flags
 						(ESoapMessage *msg,
 						 CamelEwsMessageInfo *mi);
