@@ -112,16 +112,6 @@ typedef enum {
 	E_EWS_BODY_TYPE_TEXT
 } EEwsBodyType;
 
-typedef struct {
-	gchar *as_url;
-	gchar *oab_url;
-
-	/* all the below variables are for future use */
-	gchar *oof_url;
-	gpointer future1;
-	gpointer future2;
-} EwsUrls;
-
 typedef struct {
 	gchar *id;
 	gchar *dn;
@@ -405,6 +395,15 @@ EEwsConnection *e_ews_connection_new		(const gchar *uri,
 EEwsConnection *e_ews_connection_new_full	(const gchar *uri,
 						 CamelEwsSettings *settings,
 						 gboolean allow_connection_reuse);
+void		e_ews_connection_update_credentials
+						(EEwsConnection *cnc,
+						 const ENamedParameters *credentials);
+ESourceAuthenticationResult
+		e_ews_connection_try_credentials_sync
+						(EEwsConnection *cnc,
+						 const ENamedParameters *credentials,
+						 GCancellable *cancellable,
+						 GError **error);
 const gchar *	e_ews_connection_get_uri	(EEwsConnection *cnc);
 const gchar *	e_ews_connection_get_password	(EEwsConnection *cnc);
 gchar *		e_ews_connection_dup_password	(EEwsConnection *cnc);
