@@ -33,6 +33,27 @@
 #include <libxml/tree.h>
 #include "e-ews-message.h"
 
+static SoupBuffer *
+ews_soup_chunk_allocator (SoupMessage *message,
+			  gsize max_len,
+			  gpointer user_data)
+{
+	gsize len = 32768;
+	guchar *data;
+
+	data = g_new0 (guchar, len);
+
+	return soup_buffer_new_take (data, len);
+}
+
+void
+e_ews_message_attach_chunk_allocator (SoupMessage *message)
+{
+	g_return_if_fail (SOUP_IS_MESSAGE (message));
+
+	soup_message_set_chunk_allocator (message, ews_soup_chunk_allocator, NULL, NULL);
+}
+
 static const gchar *
 convert_server_version_to_string (EEwsServerVersion version)
 {
@@ -80,10 +101,12 @@ e_ews_message_new_with_header (const gchar *uri,
 	msg = e_soap_message_new (
 		SOUP_METHOD_POST, uri, FALSE, NULL, NULL, NULL, standard_handlers);
 	if (msg == NULL) {
-		g_warning (G_STRLOC ": Could not build SOAP message");
+		g_warning ("%s: Could not build SOAP message for uri '%s'", G_STRFUNC, uri);
 		return NULL;
 	}
 
+	e_ews_message_attach_chunk_allocator (SOUP_MESSAGE (msg));
+
 	soup_message_headers_append (
 		SOUP_MESSAGE (msg)->request_headers,
 		"Content-Type", "text/xml; charset=utf-8");
