@@ -299,8 +299,8 @@ enum {
 	EWS_CONNECTION_ERROR_WIN32INTEROPERROR,
 	/* Below this point are no longer direct translations of EWS errors */
 	EWS_CONNECTION_ERROR_NORESPONSE,
-	EWS_CONNECTION_ERROR_CANCELLED,
 	EWS_CONNECTION_ERROR_AUTHENTICATION_FAILED,
+	EWS_CONNECTION_ERROR_UNAVAILABLE,
 	EWS_CONNECTION_ERROR_UNKNOWN
 };
 
